# ListCombinedUserDetailsResponse

Response object for user info query

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**limit** | **int** | Limit on the number of rows in the response | 
**combined_user_details** | [**[CombinedUserDetail]**](CombinedUserDetail.md) | The matching CombinedUserDetail objects. | [optional] 
**previous_page_email** | [**PreviousPageEmail**](PreviousPageEmail.md) |  | [optional] 
**next_page_email** | [**NextPageEmail**](NextPageEmail.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


